::: ropt.plugins.event_handler.default
    options:
        members: False
::: ropt.plugins.event_handler.default.DefaultEventHandlerPlugin
    options:
        members: False

::: ropt.plugins.event_handler._tracker.DefaultTrackerHandler
::: ropt.plugins.event_handler._store.DefaultStoreHandler
::: ropt.plugins.event_handler._observer.DefaultObserverHandler
